@@ -1,3 +1,6 @@
+#!/usr/bin/perl -w
+
+use strict;
 use Test::More tests => 65;
 
 BEGIN { use_ok('Acme::Colour'); }
